from RWTHColors.colors import *


class ColorManager:
    def __init__(self, frmt: str = "HEX"):
        if frmt not in ["HEX", "RGB"]:
            raise ValueError("frmt must be HEX or RGB not %s" % frmt)

        self.RWTHBlau = RWTHBlau()
        self.RWTHSchwarz = RWTHSchwarz()
        self.RWTHMagenta = RWTHMagenta()
        self.RWTHGelb = RWTHGelb()
        self.RWTHPetrol = RWTHPetrol()
        self.RWTHTuerkis = RWTHTuerkis()
        self.RWTHGruen = RWTHGruen()
        self.RWTHMaiGruen = RWTHMaiGruen()
        self.RWTHOrange = RWTHOrange()
        self.RWTHRot = RWTHRot()
        self.RWTHBordeaux = RWTHBordeaux()
        self.RWTHViolett = RWTHViolett()
        self.RWTHLila = RWTHLila()

        self.frmt = frmt

    @property
    def frmt(self):
        return self._frmt

    @frmt.setter
    def frmt(self, frmt: str = "HEX"):
        if frmt not in ["HEX", "RGB"]:
            raise ValueError("frmt must be HEX or RGB not %s" % frmt)

        self._frmt = frmt

        RWTHBlau.frmt = frmt
        RWTHSchwarz.frmt = frmt
        RWTHMagenta.frmt = frmt
        RWTHGelb.frmt = frmt
        RWTHPetrol.frmt = frmt
        RWTHTuerkis.frmt = frmt
        RWTHGruen.frmt = frmt
        RWTHMaiGruen.frmt = frmt
        RWTHOrange.frmt = frmt
        RWTHRot.frmt = frmt
        RWTHBordeaux.frmt = frmt
        RWTHViolett.frmt = frmt
        RWTHLila.frmt = frmt



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['rwthcolors', 'rwthcolors.colors']

package_data = \
{'': ['*']}

install_requires = \
['pytest>=6.2.5,<7.0.0']

setup_kwargs = {
    'name': 'rwthcolors',
    'version': '0.1.1',
    'description': 'Simple library that makes it easier to use RWTH CI colors in python projects',
    'long_description': '',
    'author': 'Philipp Simon Leibner',
    'author_email': 'philipp.leibner@ifs.rwth-aachen.de',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
